#include <stdio.h>
#include <stdlib.h>

#define BUF_SIZE (size_t) 4096

typedef struct {
  int time_seconds;
  float temperature;
} Datum;

int main() {
  int rc, i, data_size;
  char buf[BUF_SIZE+1];
  char *rc_cp;
  FILE *fp;
  Datum *data;

  printf("Enter filename of temperature data: ");
  rc = scanf("%s", buf);
  // scanf return number of successfully scanned items
  if (rc != 1) {
    printf("Unable to read input\n");
    return -1;
  }

  fp = fopen(buf, "r");
  if (fp == NULL) {
    printf("Unable to open file '%s' for reading\n", buf);
    return -1;
  }

  rc_cp = fgets(buf, BUF_SIZE, fp);
  if (rc_cp == NULL) {
    printf("Unable to read first line of file\n");
    return -1;
  }

  rc = sscanf(buf, "%d", &data_size);
  if (rc != 1) {
    printf("Unable to parse first line of file as integer\n");
    return -1;
  }

  data = (Datum*) malloc(data_size * sizeof(Datum));

  for(i = 0; i < data_size; i++) {
    rc_cp = fgets(buf, BUF_SIZE, fp);
    if (rc_cp == NULL) {
      printf("Unexpected EOF or file read error\n");
      return -1;
    }
    
    rc = sscanf(buf, "%d", &data[i].time_seconds);
    if (rc != 1) {
      printf("Unable to parse line as time (integer): %s\n", buf);
      return -1;
    }

    rc_cp = fgets(buf, BUF_SIZE, fp);
    if (rc_cp == NULL) {
      printf("Unexpected EOF or file read error\n");
      return -1;
    }
    
    rc = sscanf(buf, "%f", &data[i].temperature);
    if (rc != 1) {
      printf("Unable to parse line as temperature (float): %s\n", buf);
      return -1;
    }
  }

  printf("Time/s\tTemperature\n");
  for(i = 0; i < data_size; i++) {
    printf("%d\t%.2f\n", data[i].time_seconds, data[i].temperature);
  }

  fclose(fp);
  free(data);
  return 0;
}
